@@ -11,11 +11,12 @@ OUTPUT: \033[33;2m[Log]:\033[0m\033[33m Hello World!\033[0m
 
 Note: You will see logs in yellow color on your system console. In the next update you will be able to choose the colors.
 """
-log = lambda message: print("\033[33;2m[Log]:\033[0m" + " " + "\033[33m{}\033[0m".format(message))
+log = lambda message, name = "Log": print("\033[33;2m[{}]:\033[0m".format(name) + " " + "\033[33m{}\033[0m".format(message))
 log.__doc__ = """Returns the result printing in yellow color.
 
      Parameters:
-         log (message): The message that will be converted to log.
+        log(name): The name for you log.
+         log(message): The message that will be converted to log.
 
      The "message" parameter can take any type whether int or string, boolean or float.
 """
